package de.schatenseite.android.waldemar;

import android.appwidget.AppWidgetManager;
import android.content.Intent;
import android.os.Bundle;
import android.preference.EditTextPreference;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceManager;
import de.schatenseite.android.datepreference.DatePreference;

public class WaldemarPreferences extends PreferenceActivity {
	private static final String PREFIX = WaldemarPreferences.class.getPackage().getName() + ".";
	public static final String PREFERENCES_UPDATED = PREFIX + "PREFERENCES_UPDATED";
	public static final int MODE_TIMETHEN = 0;
	public static final int MODE_TIMESTART_TIMETHEN = 1;
	public static final int MODE_DURATION_TIMETHEN = 2;
	public static final int MODE_TIMESTART_DURATION = 3;
	int widgetId;
	public void enableDisablePreferences(String val) {
		EditTextPreference pref_name = (EditTextPreference)findPreference("pref_name");
		ListPreference pref_mode = (ListPreference)findPreference("pref_mode");
		EditTextPreference pref_duration = (EditTextPreference)findPreference("pref_duration");
		DatePreference pref_dateStart = (DatePreference)findPreference("pref_dateStart");
		DatePreference pref_dateThen = (DatePreference)findPreference("pref_dateThen");

		pref_name.setSummary(pref_name.getText());
		
		int index = pref_mode.findIndexOfValue(val);
		switch (index) {
		case MODE_TIMETHEN:
			pref_mode.setSummary(R.string.modeTimeThen);
			pref_duration.setEnabled(false);
			pref_duration.setSummary(R.string.duration_summary);
			pref_dateStart.setEnabled(false);
			pref_dateStart.setSummary(R.string.dateStart_summary);
			pref_dateThen.setEnabled(true);
			pref_dateThen.setSummary(pref_dateThen.getSummaryString());
			break;
		case MODE_TIMESTART_TIMETHEN:
			pref_mode.setSummary(R.string.modeTimeStartTimeThen);
			pref_duration.setEnabled(false);
			pref_duration.setSummary(R.string.duration_summary);
			pref_dateStart.setEnabled(true);
			pref_dateStart.setSummary(pref_dateStart.getSummaryString());
			pref_dateThen.setEnabled(true);
			pref_dateThen.setSummary(pref_dateThen.getSummaryString());
			break;
		case MODE_DURATION_TIMETHEN:
			pref_mode.setSummary(R.string.modeDurationTimeThen);
			pref_duration.setEnabled(true);
			pref_duration.setSummary(pref_duration.getText() + " "
					+ getApplicationContext().getString(R.string.days));
			pref_dateStart.setEnabled(false);
			pref_dateStart.setSummary(R.string.dateStart_summary);
			pref_dateThen.setEnabled(true);
			pref_dateThen.setSummary(pref_dateThen.getSummaryString());
			break;
		case MODE_TIMESTART_DURATION:
			pref_mode.setSummary(R.string.modeTimeStartDuration);
			pref_duration.setEnabled(true);
			pref_duration.setSummary(pref_duration.getText() + " "
					+ getApplicationContext().getString(R.string.days));
			pref_dateStart.setEnabled(true);
			pref_dateStart.setSummary(pref_dateStart.getSummaryString());
			pref_dateThen.setEnabled(false);
			pref_dateThen.setSummary(R.string.dateThen_summary);
			break;
		}
	}
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        PreferenceManager.setDefaultValues(this, R.xml.preferences, false);
        addPreferencesFromResource(R.xml.preferences);

        Intent intent=getIntent();
        Bundle extras=intent.getExtras();
        if (extras != null) {
            widgetId=extras.getInt(AppWidgetManager.EXTRA_APPWIDGET_ID, AppWidgetManager.INVALID_APPWIDGET_ID);
        }

        final EditTextPreference pref_name = (EditTextPreference)findPreference("pref_name");
        final ListPreference pref_mode = (ListPreference)findPreference("pref_mode");
        final EditTextPreference pref_duration = (EditTextPreference)findPreference("pref_duration");

        String val = pref_mode.getValue();
		enableDisablePreferences(val);

        pref_name.setOnPreferenceChangeListener(new Preference.OnPreferenceChangeListener() {
        	public boolean onPreferenceChange(Preference preference, Object newValue) {
        		pref_name.setSummary(newValue.toString());
        		return true;
        	}
        });
        pref_mode.setOnPreferenceChangeListener(new Preference.OnPreferenceChangeListener() {
        	public boolean onPreferenceChange(Preference preference, Object newValue) {
        		final String val = newValue.toString();
        		enableDisablePreferences(val);
        		return true;
        	}
        });
        pref_duration.setOnPreferenceChangeListener(new Preference.OnPreferenceChangeListener() {
        	public boolean onPreferenceChange(Preference preference, Object newValue) {
        		pref_duration.setSummary(newValue.toString()+" "+getApplicationContext().getString(R.string.days));
        		return true;
        	}
        });
    }

    @Override
    public void onBackPressed() {
        // this is the intent broadcast/returned to the widget
        Intent updateIntent = new Intent(this, WaldemarWidget.class);
        updateIntent.setAction(PREFERENCES_UPDATED);
        updateIntent.putExtra(AppWidgetManager.EXTRA_APPWIDGET_ID, widgetId);
        setResult(RESULT_OK, updateIntent);
        sendBroadcast(updateIntent);
        finish();
    }
}